Summary: GNU Emacs major mode for editing SGML documents
name: psgml
Version: 1.2.5
Release: 19%{?dist}
License: GPLv2+
URL: http://www.lysator.liu.se/projects/about_psgml.html
Source: ftp://ftp.lysator.liu.se/pub/sgml/psgml-%{version}.tar.gz
Patch0: psgml-install-info.patch
Group: Applications/Editors
BuildRoot: %(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)
BuildArch: noarch
%global psgmldir %{_datadir}/emacs/site-lisp/psgml/

BuildRequires: emacs
BuildRequires: sgml-common
Requires: sgml-common emacs
Requires(post): info
Requires(preun): info

%description
Emacs is an advanced and extensible editor. An Emacs major mode customizes Emacs
for editing particular types of text documents. PSGML is a major mode for SGML
(a markup language) documents.  PSGML provides several functionalities for
editing SGML documents: indentation according to element nesting depth and
identification of structural errors (but it is not a validating SGML parser);
menus and commands for inserting tags with only the contextually valid tags;
attribute values can be edited in a separate window with information about types
and defaults; structure based editing includes movement and killing; and also
several commands for folding editing.

%prep
%setup -q
%patch0 -p1 -b .install-info

# Convert to utf-8
for file in ChangeLog psgml.info psgml.texi; do
    iconv -f ISO-8859-1 -t UTF-8 -o $file.new $file && \
    touch -r $file $file.new && \
    mv $file.new $file
done

%build
# make sure we "find" etags in the installed place...
%configure
make infodir=%{_infodir} psgmldir=%{psgmldir}
cat > psgml-init.el << __ELISP__
(setq load-path (append load-path '("%{psgmldir}")))

(autoload 'sgml-mode "psgml" "Major mode for editing SGML." t)
(autoload 'xml-mode "psgml" "Major mode for editing XML." t)
(if (not (getenv "SGML_CATALOG_FILES"))
   (defvar sgml-catalog-files '("CATALOG" "catalog" "%{_sysconfdir}/sgml/catalog"))
  "*List of catalog entry files.
The files are in the format defined in the SGML Open Draft Technical
Resolution on Entity Management.")
(put 'sgml-catalog-files 'sgml-type 'list)

__ELISP__


%install
rm -rf $RPM_BUILD_ROOT

mkdir -p $RPM_BUILD_ROOT/%{psgmldir}
mkdir -p $RPM_BUILD_ROOT%{_infodir}
mkdir -p $RPM_BUILD_ROOT/%{_datadir}/sgml/cdtd

touch $RPM_BUILD_ROOT%{_infodir}/dir

make install infodir=$RPM_BUILD_ROOT%{_infodir} \
  prefix=$RPM_BUILD_ROOT/%{prefix} \
  psgmldir=$RPM_BUILD_ROOT/%{psgmldir} \
  lispdir=$RPM_BUILD_ROOT/%{psgmldir}

make install-info infodir=$RPM_BUILD_ROOT%{_infodir}

gzip $RPM_BUILD_ROOT%{_infodir}/*.info

rm -f $RPM_BUILD_ROOT%{_infodir}/dir

mkdir -p $RPM_BUILD_ROOT%{_datadir}/emacs/site-lisp/site-start.d
install -p -m644 psgml-init.el $RPM_BUILD_ROOT%{_datadir}/emacs/site-lisp/site-start.d

%clean
rm -rf $RPM_BUILD_ROOT

%post
install-info --info-dir=%{_infodir} %{_infodir}/psgml.info || :
install-info --info-dir=%{_infodir} %{_infodir}/psgml-api.info || :

%preun
if [ "$1" = 0 ] ; then
  install-info --info-dir=%{_infodir} --delete %{_infodir}/psgml.info || :
  install-info --info-dir=%{_infodir} --delete %{_infodir}/psgml-api.info || :
fi

%files
%defattr(-,root,root,-)
%doc psgml.ps psgml.texi README.psgml ChangeLog
%dir %{psgmldir}
%{psgmldir}/*
%{_datadir}/emacs/site-lisp/site-start.d/*
%{_datadir}/sgml/cdtd
%{_infodir}/psgml*

%changelog
* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.5-19
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.5-18
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.5-17
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.5-16
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.5-15
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.5-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.5-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Feb  8 2010 Alex Lancaster <alexlan[AT]fedoraproject org> - 1.2.5-12
- Updates for merge review (#226321)
- Add URL to upstream
- Fixed {Build}Requires to use sgml-common and emacs
- Make postun a preun
- Convert files to UTF-8
- Use macros throughout
- Fix scriptlets
- Add some missing %%doc files
- Fixes to quiet rpmlint
- Remove some non-existent catalog files used with old DTDs

* Mon Aug 10 2009 Ville Skyttä <ville.skytta@iki.fi> - 1.2.5-11
- Convert specfile to UTF-8.

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.5-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.5-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Fri Jun 13 2008 Jon Stanley <jonstanley@gmail.com> 1.2.5-8
- Rebuild

* Wed May 21 2008 Tom "spot" Callaway <tcallawa@redhat.com> 1.2.5-7
- fix license tag

* Mon Mar 12 2007 Florian La Roche <laroche@redhat.com> 1.2.5-6.fc7
- rebuild

* Mon Jan 22 2007 Adam Tkac <atkac redhat com> 1.2.5-5.fc7
- added dist macro
- fixed install-info scriptlet failures (#223715), patch from Ville Skytta
  (ville.skytta "antispam" iki.fi)

* Wed Jun 07 2006 Jitka Kudrnacova <jkudrnac@redhat.com> 1.2.5-4.3
- rebuilt 

* Mon Feb 27 2006 Jitka Kudrnacova <jkudrnac@redhat.com> 1.2.5-4.2
- fixed compilation

* Fri Dec 09 2005 Jesse Keating <jkeating@redhat.com>
- rebuilt

* Wed Oct  6 2004 Jens Petersen <petersen@redhat.com> - 1.2.5-4
- drop requirement on emacs for emacs-nox users (Lars Hupfeldt Nielsen, 134479)

* Thu May 20 2004 Tim Waugh <twaugh@redhat.com> 1.2.5-3
- Build requires emacs (bug #123781).

* Fri Feb 13 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Tue Oct 21 2003 Florian La Roche <Florian.LaRoche@redhat.de>
- add a %%clean specfile target

* Mon Apr  7 2003 Tim Waugh <twaugh@redhat.com> 1.2.5-1
- 1.2.5 (bug #88045).

* Wed Jan 22 2003 Tim Powers <timp@redhat.com>
- rebuilt

* Wed Nov 20 2002 Tim Powers <timp@redhat.com>
- rebuild in current collinst

* Fri Jun 21 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Sun May 26 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Fri Feb 22 2002 Tim Waugh <twaugh@redhat.com> 1.2.3-3
- Rebuild in new environment.

* Wed Jan 09 2002 Tim Powers <timp@redhat.com> 1.2.3-2
- automated rebuild

* Thu Nov 15 2001 Tim Waugh <twaugh@redhat.com> 1.2.3-1
- 1.2.3.  Incorporates both patches we had.

* Fri Nov  2 2001 Tim Waugh <twaugh@redhat.com> 1.2.2-4
- Make sure %%post scriplet doesn't fail if --excludedocs is used.

* Thu Nov  1 2001 Tim Waugh <twaugh@redhat.com> 1.2.2-3
- Apply patch to make it work with emacs 21 (bug #55094).

* Mon Oct  1 2001 Tim Waugh <twaugh@redhat.com> 1.2.2-2
- Own psgml directory (bug #51381).

* Tue Aug 21 2001 Tim Waugh <twaugh@redhat.com> 1.2.2-1
- s/Copyright/License/.
- 1.2.2.
- Apply multibyte patch so that DTD preparsing works with DocBook 4.0 up.

* Thu Jan 11 2001 Tim Waugh <twaugh@redhat.com>
- Search catalog and /etc/sgml/catalog too.
- Put cdtd in /usr/share/sgml not /usr/lib/sgml.

* Thu Nov 30 2000 Trond Eivind Glomsrød <teg@redhat.com>
- use new emacs init scheme

* Mon Nov 13 2000 Tim Waugh <twaugh@redhat.com>
- autoload xml-mode (bug #20602)

* Thu Oct 19 2000 Trond Eivind Glomsrød <teg@redhat.com>
- don't try to touch the site-start.el file
- use %%{_tmppath}
- don't %%define %%version above the "Version: " part
  of the header

* Wed Aug 16 2000 Bill Nottingham <notting@redhat.com>
- tweak summary

* Wed Jul 12 2000 Prospector <bugzilla@redhat.com>
- automatic rebuild

* Sat Jun 10 2000 Bill Nottingham <notting@redhat.com>
- rebuild for FHS stuff

* Wed Feb 16 2000 Bill Nottingham <notting@redhat.com>
- look in old sgml-tools dirs for catalogs, to catch linuxdoc

* Thu Feb  3 2000 Bill Nottingham <notting@redhat.com>
- handle compressed man pages

* Wed Jan  5 2000 Bill Nottingham <notting@redhat.com>
- clean up spec file some

* Wed Nov 24 1999 Tim Powers <timp@redhat.com>
- came in on my day off to buld this package, feel special?
- updated to 1.2.1

* Mon Aug 30 1999 Tim Powers <timp@redhat.com>
- changed group
- changed buildroot toe be in /var/tmp
- added %%defattr

* Tue Jul 21 1999 Tim Powers <timp@redhat.com>
- rebuilt for 6.1

* Fri Apr 23 1999 Michael K. Johnson <johnsonm@redhat.com>
- PATH hack to protect "make install" from install-info
- %%doc path fixed
- protect postun from uninstall
- Moved $V outside of '' so that it gets interpolated

* Thu Apr 22 1999 Owen Taylor <otaylor@redhat.com>
- Upgrade to psgml-1.0.3
- Made noarch

